==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/plugin/lang/lv/lang.php <==
<?php
/**
 * Latvian, Lettish language file
 *
 * @author Aivars Miška <allefm@gmail.com>
 */
$lang['menu']                  = 'Moduļu pārvaldība';
$lang['download']              = 'Lejupielādāt un instalēt jaunu moduli.';
$lang['manage']                = 'Instalētie moduļi';
$lang['btn_info']              = 'uzziņa';
$lang['btn_update']            = 'atjaunināt';
$lang['btn_delete']            = 'dzēst';
$lang['btn_settings']          = 'parametri';
$lang['btn_download']          = 'Lejupielādēt';
$lang['btn_enable']            = 'Saglabāt';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalēts:';
$lang['lastupdate']            = 'Atjaunināts:';
$lang['source']                = 'Avots:';
$lang['unknown']               = 'nav zināms';
$lang['updating']              = 'Atjauninu...';
$lang['updated']               = 'Modulis %s veiksmīgi atjaunināts';
$lang['updates']               = 'Veiksmīgi atjaunināti moduļi:';
$lang['update_none']           = 'Jauninājums nav atrasts';
$lang['deleting']              = 'Dzēšu...';
$lang['deleted']               = 'Modulis %s dzēsts';
$lang['downloading']           = 'Lejupielādēju...';
$lang['downloaded']            = 'Modulis %s veiksmīgi instalēts';
$lang['downloads']             = 'Veiksmīgi instalēti moduļi: ';
$lang['download_none']         = 'Neviens modulis nav atrasts vai arī gadījusies nezinām kļūme lejupielādes un instalācijas gaitā.';
$lang['plugin']                = 'Modulis:';
$lang['components']            = 'Sastāvdaļas';
$lang['noinfo']                = 'Modulis nesniedz informāciju, tas varbūt ir bojāts.';
$lang['name']                  = 'Nosaukums:';
$lang['date']                  = 'Datums:';
$lang['type']                  = 'Tips:';
$lang['desc']                  = 'Apraksts:';
$lang['author']                = 'Autors:';
$lang['www']                   = 'Mājaslapa:';
$lang['error']                 = 'Gadījās nezināma kļūme.';
$lang['error_download']        = 'Nevar lejupielādēt moduļa failu %s';
$lang['error_badurl']          = 'Aizdomas par aplamu URL - jo no tā nevar noteikt faila vārdu.';
$lang['error_dircreate']       = 'Nevar izveidot pagaidu direktoriju, kur saglabāt lejupielādēto. ';
$lang['error_decompress']      = 'Moduļu pārvaldnieks nevar atspiest lejupielādēto failu. Vai nu neizdevusi es lejupielāde, mēģiniet atkārtot, vai arī nezinām arhīva formāts un tad  modulis jāielādē un jāinstalē tev pašam.';
$lang['error_copy']            = 'Faila kopēšanas kļūda instalējot moduli<em>%s</em>: disks pārpildīts vai aplamas piekļuves tiesības. Rezultātā var iegūt daļēji instalētu moduli un nestabilu Wiki sistēmu.';
$lang['error_delete']          = 'Kļūme dzēšot moduli <em>%s</em>. Ticamākais iemesls ir direktorijas pieejas tiesību trūkums. ';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/plugin/lang/lv/lang.php <==
<?php
/**
 * Latvian, Lettish language file
 *
 * @author Aivars Miška <allefm@gmail.com>
 */
$lang['menu']                  = 'Moduļu pārvaldība';
$lang['download']              = 'Lejupielādēt un instalēt jaunu moduli.';
$lang['manage']                = 'Instalētie moduļi';
$lang['btn_info']              = 'uzziņa';
$lang['btn_update']            = 'atjaunināt';
$lang['btn_delete']            = 'dzēst';
$lang['btn_settings']          = 'parametri';
$lang['btn_download']          = 'Lejupielādēt';
$lang['btn_enable']            = 'Saglabāt';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalēts:';
$lang['lastupdate']            = 'Atjaunināts:';
$lang['source']                = 'Avots:';
$lang['unknown']               = 'nav zināms';
$lang['updating']              = 'Atjauninu...';
$lang['updated']               = 'Modulis %s veiksmīgi atjaunināts';
$lang['updates']               = 'Veiksmīgi atjaunināti moduļi:';
$lang['update_none']           = 'Jauninājums nav atrasts';
$lang['deleting']              = 'Dzēšu...';
$lang['deleted']               = 'Modulis %s dzēsts';
$lang['downloading']           = 'Lejupielādēju...';
$lang['downloaded']            = 'Modulis %s veiksmīgi instalēts';
$lang['downloads']             = 'Veiksmīgi instalēti moduļi: ';
$lang['download_none']         = 'Neviens modulis nav atrasts vai arī gadījusies nezinām kļūme lejupielādes un instalācijas gaitā.';
$lang['plugin']                = 'Modulis:';
$lang['components']            = 'Sastāvdaļas';
$lang['noinfo']                = 'Modulis nesniedz informāciju, tas varbūt ir bojāts.';
$lang['name']                  = 'Nosaukums:';
$lang['date']                  = 'Datums:';
$lang['type']                  = 'Tips:';
$lang['desc']                  = 'Apraksts:';
$lang['author']                = 'Autors:';
$lang['www']                   = 'Mājaslapa:';
$lang['error']                 = 'Gadījās nezināma kļūme.';
$lang['error_download']        = 'Nevar lejupielādēt moduļa failu %s';
$lang['error_badurl']          = 'Aizdomas par aplamu URL - jo no tā nevar noteikt faila vārdu.';
$lang['error_dircreate']       = 'Nevar izveidot pagaidu direktoriju, kur saglabāt lejupielādēto. ';
$lang['error_decompress']      = 'Moduļu pārvaldnieks nevar atspiest lejupielādēto failu. Vai nu neizdevusi es lejupielāde, mēģiniet atkārtot, vai arī nezinām arhīva formāts un tad  modulis jāielādē un jāinstalē tev pašam.';
$lang['error_copy']            = 'Faila kopēšanas kļūda instalējot moduli<em>%s</em>: disks pārpildīts vai aplamas piekļuves tiesības. Rezultātā var iegūt daļēji instalētu moduli un nestabilu Wiki sistēmu.';
$lang['error_delete']          = 'Kļūme dzēšot moduli <em>%s</em>. Ticamākais iemesls ir direktorijas pieejas tiesību trūkums. ';
$lang['enabled']               = 'Modulis %s pieslēgts.';
$lang['notenabled']            = 'Moduli %s nevar pieslēgt, pārbaudi failu tiesības.';
$lang['disabled']              = 'Modulis %s atslēgts.';
$lang['notdisabled']           = 'Moduli %s nevar atslēgt, pārbaudi failu tiesības.';
$lang['packageinstalled']      = 'Moduļu paka (pavisam kopā %d: %s) veiksmīgi uzstādīti.';
